# Datasets

## random_sentence_tiny.txt
  - Description
    - This dataset is beig generated by random sentence generator with ~100 unique sentences.
    - This rest of sentence is being duplicated.
    - The label set [positive, negative, neutral] was random generated.
  - Size: 100 dummy samples
